
import javafx.application.Application;
import javafx.geometry.Insets;
import javafx.geometry.Pos;
import javafx.scene.Scene;
import javafx.scene.control.Alert;
import javafx.scene.control.Label;
import javafx.scene.layout.HBox;
import javafx.scene.layout.Pane;
import javafx.scene.layout.VBox;
import javafx.scene.paint.Color;
import javafx.scene.shape.Rectangle;
import javafx.stage.Stage;
import javafx.scene.Group;

/**
 * Clase que genera la vista de la malla.
 */

public class mallaView extends Group{

    private malla malla;

    private Label porcentajeAprobados = new Label();

    /**
     * Constructor que enlaza el objeto malla con los elementos visuales.
     * @param malla La malla a enlazar.
     */
    public mallaView(malla malla) {
        this.malla = malla;
        this.malla.setMallaView(this);
    }

    /**
     * Fija el texto a mostrar en la etiqueta de créditos aprobados.
     */
    public void setPorcetajeAprobado(){
        porcentajeAprobados.setText("Porcentaje de créditos aprobados: " + malla.getPorcentajeCreditos() + "%");
    }
    
    /**
     * Crea un elemnto visual rectangular.
     * @param text  Texto a mostrar en el rectángulo.
     * @return  Elemento visual rectangular.
     */
    private Pane createBorderedElement(String text) {
        Rectangle border = new Rectangle(260, 30);
        border.setStroke(Color.BLACK);
        border.setFill(null);
        Label label = new Label(text);
        Pane container = new Pane();
        container.getChildren().addAll(border, label);
        container.setPadding(new Insets(5));
        return container;
    }

    /**
     * Crea la grilla donde se ubican los ramos.
     * @param carreraBox    Elemento visual general donde van todos los ramos.
     */
    public void createGrid(VBox carreraBox){
        HBox years = new HBox();
        years.setSpacing(0);
        years.setAlignment(Pos.CENTER_LEFT);
        for(int i = 1; i < 7; i++){
            String text = "YEAR " + Integer.toString(i);
            Pane year = createBorderedElement(text);
            year.setStyle("-fx-font-size: 17px;");
            years.getChildren().add(year);
        }

        HBox semestres = new HBox();
        semestres.setSpacing(62);
        semestres.setAlignment(Pos.CENTER_LEFT);
        for(int i = 1; i < 13; i++){
            if(i == 9 || i == 11)
            {
                Label verano = new Label("Verano   ");
                verano.setStyle("-fx-font-size: 15px;");
                semestres.getChildren().add(verano);
            }
            String text = "Semestre " + Integer.toString(i);
            Label sems = new Label(text);
            sems.setStyle("-fx-font-size: 15px;");
            semestres.getChildren().add(sems);
        }

        carreraBox.getChildren().addAll(years, semestres);
    }

    /**
     * Permite agregar los elementos visuales que muestran el total de créditos y el porcentaje aprovado.
     * @param carreraBox    Elemento visual general donde van todos los ramos.
     */
    public void addCounters(VBox carreraBox){
        HBox contCredit = new HBox();// contador de creditos
        contCredit.setSpacing(0);
        contCredit.setAlignment(Pos.BOTTOM_CENTER);
        Label creditos = new Label("Creditos Totales" + ":" + malla.getTotalCredits());
        creditos.setStyle("-fx-font-size: 17px; -fx-border-color: black; -fx-border-insets: 5px; -fx-padding: 5px");
        contCredit.getChildren().add(creditos);


        HBox contPorcent = new HBox();// contador de creditos
        contCredit.setSpacing(0);
        contCredit.setAlignment(Pos.BOTTOM_CENTER);
        Label label = new Label("00");
        porcentajeAprobados.setText("Porcentaje de créditos aprobados: " + malla.getPorcentajeCreditos());
        porcentajeAprobados.setStyle("-fx-font-size: 17px; -fx-border-color: black; -fx-border-insets: 5px; -fx-padding: 5px");
        contCredit.getChildren().add(porcentajeAprobados);

        carreraBox.getChildren().add(contCredit);
    }

    /**
     * Agrega vista de ramos a la vista de malla.
     * @param carreraBox    Elemento visual general donde van todos los ramos.
     * @param cantidad_ramos    Cantidad de ramos en la malla.
     */
    public void addRamos(VBox carreraBox, int cantidad_ramos){
        HBox semestreView = new HBox();
        semestreView.setSpacing(15);

        if (!malla.getRamos().isEmpty()) {
            VBox[] mallaViews = new VBox[14];

            for(int i = 0; i < 14; i++){
                mallaViews[i] = new VBox();
                mallaViews[i].setAlignment(Pos.TOP_CENTER);
                mallaViews[i].setSpacing(10);
            }

            for(int i = 0; i < cantidad_ramos; i++){
                ramo ramo = malla.getRamos().get(i); 
                switch (ramo.getSemestre()) {
                    case "S01":
                        ramoView ramoView1 = new ramoView(ramo, malla);
                        mallaViews[0].getChildren().add(ramoView1);
                        break;
                    case "S02":
                        ramoView ramoView2 = new ramoView(ramo, malla);
                        mallaViews[1].getChildren().add(ramoView2);
                        break;
                    case "S03":
                        ramoView ramoView3 = new ramoView(ramo, malla);
                        mallaViews[2].getChildren().add(ramoView3);
                        break;
                    case "S04":
                        ramoView ramoView4 = new ramoView(ramo, malla);
                        mallaViews[3].getChildren().add(ramoView4);
                        break;
                    case "S05":
                        ramoView ramoView5 = new ramoView(ramo, malla);
                        mallaViews[4].getChildren().add(ramoView5);
                        break;
                    case "S06":
                        ramoView ramoView6 = new ramoView(ramo, malla);
                        mallaViews[5].getChildren().add(ramoView6);
                        break;
                    case "S07":
                        if(ramo.getNombre().equals("Práctica Industrial Aprobada"))
                        {
                            ramoView practicaIndustrial = new ramoView(ramo, malla);
                            mallaViews[8].getChildren().add(practicaIndustrial);
                        }
                        else{
                            ramoView ramoView7 = new ramoView(ramo, malla);
                            mallaViews[6].getChildren().add(ramoView7);  
                        }
                        break;
                    case "S08":
                        ramoView ramoView8 = new ramoView(ramo, malla);
                        mallaViews[7].getChildren().add(ramoView8);
                        break;
                    case "S09":
                        ramoView ramoView9 = new ramoView(ramo, malla);
                        mallaViews[9].getChildren().add(ramoView9);
                        break;
                    case "S10":
                        ramoView ramoView10 = new ramoView(ramo, malla);
                        mallaViews[10].getChildren().add(ramoView10);
                        break;
                    case "S11":
                        if(ramo.getNombre().equals("Práctica Profesional Aprobada"))
                        {
                            ramoView practicaProfesional = new ramoView(ramo, malla);
                            mallaViews[11].getChildren().add(practicaProfesional);
                        }
                        else{
                            ramoView ramoView11 = new ramoView(ramo, malla);
                            mallaViews[12].getChildren().add(ramoView11);;  
                        }
                        break;
                    case "S12":
                        ramoView ramoView12 = new ramoView(ramo, malla);
                        mallaViews[13].getChildren().add(ramoView12);
                        break;
                    default:
                        break;
                }
            }
            semestreView.getChildren().addAll(mallaViews);
            carreraBox.getChildren().addAll(semestreView);
        
            
        } else {
            System.out.println("La lista de ramos está vacía");
        }
    }

}