import javafx.application.Application;
import javafx.geometry.Pos;
import javafx.scene.Scene;
import javafx.scene.layout.VBox;
import javafx.stage.Stage;
import java.util.ArrayList;
import java.io.*;
import javafx.scene.layout.HBox;
import javafx.scene.control.Label;
import javafx.scene.layout.Pane;
import javafx.geometry.Insets;
import javafx.scene.paint.Color;
import javafx.scene.shape.Rectangle;

/**
 * Clase principal de la aplicación. Permite leer el archivo de entrada y generar elementos visuales de la malla.
 */
public class proyecto extends Application {

    private malla malla;
    private mallaView mv;
    private int cantidad_ramos = 0;

    /**
     * Lee el archivo de entrada y genera los objetos ramo y malla correspondientes.
     * @param file Archivo de entrada. Usualmente entregado por el argumento del main (proyecto.java)
     * @throws IOException  En caso de errores de lectura.
     */
    public void readFile(File file) throws IOException {
        BufferedReader br = new BufferedReader(new FileReader(file));
        br.readLine();
        String line = null; //para saltarse la primer linea (junto con br.readline())
        ArrayList<ramo> ramos = new ArrayList<ramo>();
        while ((line = br.readLine()) != null) {
            String[] data = line.split(",");
            ramo r = new ramo(data[0], data[1], data[2], data[3], data[4], data[5], data[6], data[7]);
            ramos.add(r);
        }
        malla = new malla();
        for (ramo r : ramos) {
            malla.addRamo(r);
            cantidad_ramos++;
        }
        br.close();
    }
    /**
     * Genera la ventana y elementos visuales de la malla.
     * @param primaryStage  Grupo donde están todos los elementos visuales.
     * @throws IOException  En caso de errores de lectura del archivo.
     */
    public void start(Stage primaryStage) throws IOException {
        File inputFile = new File("test.txt");
        if (!inputFile.exists()) {
            System.out.println("El archivo de entrada no existe");
            System.exit(-1);
        }

        readFile(inputFile);
        VBox carrera = new VBox();
        carrera.setSpacing(5);
        mv = new mallaView(malla);
        mv.createGrid(carrera);
        mv.addRamos(carrera, cantidad_ramos);
        mv.addCounters(carrera);

        Scene scene = new Scene(carrera, 400, 200);

        primaryStage.setTitle("Malla Interactiva");
        primaryStage.setScene(scene);
        primaryStage.show();

        //System.out.println("Creditos totales: " + malla.getTotalCredits());
        //System.out.println("Porcentaje de créditos aprobados: "+malla.getPorcentajeCreditos());
    }

    public static void main(String[] args) {
        launch(args);
    }
}