public class ramo {
    private String sem;
    private String sigla;
    private String nombre;
    private String eje;
    private String mencion;
    private String categoria;
    private String creditos;
    private String pre;
    private Boolean aprobado;

    /**
     * Constructor de ramo. Permite crear el objeto con toda su información relevante.
     * @param sem   Semestre al cual pertenece el ramo.
     * @param sigla Sigla del ramo.
     * @param nombre    Nombre del ramo.
     * @param eje   Eje formativo al cual pertenece el ramo.
     * @param mencion   Mención a la cual pertenece el ramo. No todos los ramos son de mención.
     * @param categoria Categoría a la que pertenece el ramo. Define el color del ramo en la malla.
     * @param creditos  Cantidad de créditos SCT que posee el ramo.
     * @param pre   Ramos que son pre-requisitos para poder cursar el ramo.
     */
    public ramo(String sem, String sigla, String nombre, String eje, String mencion, String categoria,
     String creditos, String pre) {
        this.sem = sem;
        this.sigla = sigla;
        this.nombre = nombre;
        this.eje = eje;
        this.mencion = mencion;
        this.categoria = categoria;
        this.creditos = creditos;
        this.pre = pre;
        this.aprobado = false;
    }

    /**
     * Obtiene el semestre del ramo.
     * @return Semestre al cual pertenece el ramo.
     */
    public String getSemestre() {
        return sem;
    }

    /**
     * Obtiene la sigla del ramo.
     * @return Sigla del ramo.
     */
    public String getSigla() {
        return sigla;
    }

    /**
     * Obtiene el nombre completo del ramo.
     * @return Nombre completo del ramo.
     */
    public String getNombre() {
        return nombre;
    }

    /**
     * Obtiene el eje al cual pertenece el ramo.
     * @return Eje al cual pertenece el ramo.
     */
    public String getEje() {
        return eje;
    }

    /**
     * Obtiene la mención a la que pertenece el ramo.
     * @return  Mención a la que pertenece el ramo.
     */
    public String getMencion(){
        return mencion;
    }
    
    /**
     * Obtiene la categoría del ramo.
     * @return  Categoría del ramo.
     */
    public String getCategoria(){
        return categoria;
    }

    /**
     * Obtiene los créditos del ramo.
     * @return  Créditos del ramo.
     */
    public String getCreditos() {
        return creditos;
    }

    /**
     * Permite redefinir la cantidad de créditos del ramo.
     * @param creditos  Cantidad de créditos nuevos que tendrá el ramo.
     */
    public void setCreditos(String creditos){
        this.creditos = creditos;
    }

    /**
     * Obtiene los pre-requisitos del ramo. Como se encuentra al 5/7/23 todos los pre-requisitos vienen en un solo string.
     * @return  Ramos que son pre-requisitos del ramo.
     */
    public String getPre() {
        return pre;
    }

    /**
     * Permite conmutar el estado del ramo entre aprobado y no aprobado.
     */
    public void changeState(){
        aprobado = !aprobado;
        //System.out.println("El ramo está " + aprobado);
    }

    /**
     * Obtiene el estado aprobado o no aprobado del ramo.
     * @return  True si el ramo está marcado como aprobado, False en otro caso.
     */
    public Boolean getState(){
        return aprobado;
    }
}