import javafx.scene.input.MouseEvent;
import javafx.geometry.Pos;
import javafx.scene.control.Label;
import javafx.scene.layout.VBox;
import javafx.scene.paint.Color;
import javafx.scene.shape.Rectangle;
import javafx.stage.Stage;
import javafx.scene.Group;
import javafx.event.EventHandler;
import javafx.scene.shape.Line;
import javafx.scene.input.MouseButton;
import javafx.scene.control.ContextMenu;
import javafx.scene.control.MenuItem;
import javafx.scene.control.TextInputDialog;

/**
 * Componentes visuales de los ramos.
 */
public class ramoView extends Group {

    private malla malla;
    private ramo ramoModel;
    private Rectangle square;
    private proyecto pr;

    private boolean isCrossed;
    private Line diagonalLine;


    /**
     * Constructor que enlaza el la vista del ramo con el objeto ramo y la malla correspondiente.
     * @param ramo_x Objeto ramo a enlazar.
     * @param malla Malla a la que pertenece el ramo.
     */
    public ramoView(ramo ramo_x, malla malla) {
        this.malla = malla;
        ramoModel = ramo_x;
        makeRamoView();
    }
    /**
     * Genera los aspectos visuales del ramo, como color, tamaño, texto para las etiquetas, y construye los eventos para la 
     * programación conducida por eventos.
     */
    private void makeRamoView() {

        square = new Rectangle(120, 100);
        square.setStroke(Color.BLACK);
        square.setStrokeWidth(2);
        switch (ramoModel.getCategoria()) { //Rellena con el color acorde a la categoría del ramo.
            case "Formación en General":
                square.setFill(Color.LIGHTBLUE);
                break;
            case "Formación en Ciencias Básicas":
                square.setFill(Color.LIGHTGREEN);
                break;
            case "Formación en Ciencias Sociales y Humanidades":
                square.setFill(Color.YELLOW);
                break;
            case "Formación en Ciencias de la Ingeniería":
                square.setFill(Color.ORANGE);
                break;
            case "Asignaturas Libres":
                square.setFill(Color.CYAN);
                break;
            case "Asignaturas Complementarias":
                square.setFill(Color.PINK);
                break;
            case "Formación en Ingenierías Aplicadas":
                square.setFill(Color.LIGHTGRAY);
                break;            
            default:
                square.setFill(Color.LIGHTBLUE);
                break;
        }

        diagonalLine = new Line(0, 0, square.getWidth(), square.getHeight());
        diagonalLine.setStroke(Color.RED);
        diagonalLine.setStrokeWidth(3);
        diagonalLine.setVisible(false);


        Label nameLabel = new Label(ramoModel.getNombre());
        nameLabel.setStyle("-fx-font-size: 15px;");
        nameLabel.setMaxWidth(105);
        nameLabel.setWrapText(true);

        Label numberLabel = new Label(ramoModel.getSigla());
        numberLabel.setStyle("-fx-font-size: 12px;");
        numberLabel.setMaxWidth(90);
        numberLabel.setWrapText(true);

        Label creditosLabel = new Label(ramoModel.getCreditos());
        creditosLabel.setStyle("-fx-font-size: 12px;");
        creditosLabel.setMaxWidth(100);
        creditosLabel.setWrapText(true);

        VBox labelsContainer = new VBox(nameLabel, numberLabel);
        labelsContainer.setAlignment(Pos.CENTER);


        VBox container = new VBox(labelsContainer, creditosLabel);
        container.setAlignment(Pos.CENTER);
        container.setStyle("-fx-padding: 0 4px;");
        
        ContextMenu contextMenu = new ContextMenu();
        MenuItem changeNameMenuItem = new MenuItem("Cambiar Ramo");
        changeNameMenuItem.setOnAction(event -> {
            TextInputDialog dialog = new TextInputDialog(nameLabel.getText());
            dialog.setTitle("Cambiar nombre Ramo");
            dialog.setHeaderText(null);
            dialog.setContentText("Ingrese nombre del ramo:");
            

            dialog.showAndWait().ifPresent(newName -> {
                nameLabel.setText(newName);
                square.setFill(Color.BEIGE);
            });  
        });

        MenuItem changeNumberMenuItem = new MenuItem("Cambiar Sigla");
        changeNumberMenuItem.setOnAction(event -> {
            TextInputDialog dialog = new TextInputDialog(numberLabel.getText());
            dialog.setTitle("Cambiar Sigla");
            dialog.setHeaderText(null);
            dialog.setContentText("Ingrese sigla del ramo:");

            dialog.showAndWait().ifPresent(newNumber -> {
                numberLabel.setText(newNumber);
            });
        });

        MenuItem changeCreditosMenuItem = new MenuItem("Cambio Creditos");
        changeCreditosMenuItem.setOnAction(event -> {
            TextInputDialog dialog = new TextInputDialog(creditosLabel.getText());
            dialog.setTitle("Cambio Creditos");
            dialog.setHeaderText(null);
            dialog.setContentText("Ingrese creditos del ramo:");
            

            dialog.showAndWait().ifPresent(newCreditos -> {
                creditosLabel.setText(newCreditos);
                ramoModel.setCreditos(newCreditos);
            });
        });
        contextMenu.getItems().addAll(changeNameMenuItem, changeNumberMenuItem, changeCreditosMenuItem);

        this.setOnMouseClicked(event -> {   //actualizar estados y colores al hacer click en un ramo
            if (event.getButton() == MouseButton.PRIMARY) {
                this.ramoModel.changeState();
                if (diagonalLine.isVisible()) {
                    diagonalLine.setVisible(false);
                    square.setOpacity(1.0);
                } else {
                    diagonalLine.setVisible(true);
                    square.setOpacity(0.5);
                }
                malla.getMallaView().setPorcetajeAprobado();
            } else if (event.getButton() == MouseButton.SECONDARY) {
                contextMenu.show(this, event.getScreenX(), event.getScreenY());
            }
        });


        getChildren().addAll(square, diagonalLine, container);
    }
}